'use strict';

/**
 * Module dependencies.
 */

var isObject = require('isobject');


/**
 * Initialize.
 *
 * http://help.userpilot.com/
 *
 * @api public
 */

Userpilot.prototype.initialize = function(appToken) {
  this.load(appToken);
};

/**
 * Loaded?
 *
 * @api private
 * @return {boolean}
 */

Userpilot.prototype.loaded = function() {
  return isObject(window.userpilot);
};

/**
 * Load the Userpilot library.
 *
 * @api private
 * @param {Function} callback
 */

Userpilot.prototype.load = function(appToken) {
  var id = appToken || 'iv';
  load('//deploy.userpilot.io/' + id + '.js');
};

/**
 * Page.
 *
 * http://help.userpilot.io/docs#page
 *
 * @api public
 * @param {Page} page
 */

Userpilot.prototype.reload = function() {
  window.userpilot.reload();
};

/**
 * Identify.
 *
 * http://help.userpilot.io/docs#identify
 *
 * @api public
 * @param {Identify} identify
 */

Userpilot.prototype.identify = function(userId, identify) {
  var traits = identify.traits();
  if (traits.createdAt) {
    traits.created_at = traits.createdAt;
    delete traits.createdAt;
  } 

  window.userpilot.identify(userId, traits);
};

/**
 * Track.
 *
 * http://help.userpilot.io/docs#track
 *
 * @api public
 * @param {Track} track
 */

Userpilot.prototype.track = function(event, meta) {
  window.userpilot.track(event, meta);
};
